#
# spec file for package python-catkin-pkg
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define commands create_pkg find_pkg generate_changelog package_version prepare_release tag_changelog test_changelog
%define skip_python2 1
Name:           python-catkin-pkg
Version:        0.4.24
Release:        2.13
Summary:        Catkin package library
License:        BSD-3-Clause
URL:            https://wiki.ros.org/catkin_pkg
Source:         https://github.com/ros-infrastructure/catkin_pkg/archive/%{version}.tar.gz
# https://github.com/ros-infrastructure/catkin_pkg/commit/b5c6812b40fa31da91ee560dda7c6e470dedcfb8.diff
Patch0:         python-catkin-pkg-no-mock.patch
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-docutils
Requires:       python-pyparsing
Requires:       python-python-dateutil
Requires:       python-setuptools
Requires(post): update-alternatives
Requires(postun):update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module docutils}
BuildRequires:  %{python_module flake8}
BuildRequires:  %{python_module pyparsing}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module python-dateutil}
# /SECTION
%python_subpackages

%description
Library for retrieving information about catkin packages.

%prep
%setup -q -n catkin_pkg-%{version}
%autopatch -p1

%build
%python_build

%install
%python_install
for c in %{commands}; do
  %python_clone -a %{buildroot}%{_bindir}/catkin_$c
done
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export PYTHONPATH=$PWD/src
# flake8 line length checks failing (E501)
%pytest -k 'not test_flake8'

%post
for c in %{commands}; do
  %python_install_alternative catkin_$c
done

%postun
for c in %{commands}; do
  %python_uninstall_alternative catkin_$c
done

%files %{python_files}
%license LICENSE
%python_alternative %{_bindir}/catkin_create_pkg
%python_alternative %{_bindir}/catkin_find_pkg
%python_alternative %{_bindir}/catkin_generate_changelog
%python_alternative %{_bindir}/catkin_package_version
%python_alternative %{_bindir}/catkin_prepare_release
%python_alternative %{_bindir}/catkin_tag_changelog
%python_alternative %{_bindir}/catkin_test_changelog
%{python_sitelib}/*

%changelog
* Wed Mar  9 2022 pgajdos@suse.com
- do not require mock for build
- added patches
  https://github.com/ros-infrastructure/catkin_pkg/commit/b5c6812b40fa31da91ee560dda7c6e470dedcfb8
  + python-catkin-pkg-no-mock.patch
* Sat Jan 15 2022 Dirk Müller <dmueller@suse.com>
- update to 0.4.24:
  * stop using undocumented docutils api
  * remove validate_metapacakge wrapper
  * flake8 warnings
  * test fixes
  * add option to show only merge commits
  * compare dependencies with all attributes
* Wed Jul 29 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.4.22:
  * catkin_generate_changelog: hack to allow tag version prefixed with v
  * add GitLab auto linking for issues in catkin_generate_changelog
  * enable releasing from Focal with stdeb 0.9.1
  * fix deprecation warnings in tests
  * pass stricter pycodestyle 2.6 checks
  * Restore compatibility with pyparsing < 1.5.7
  * Respect (AMENT|COLCON|CATKIN)_IGNORE directories
  * bump min CMake version to avoid CMP0048 warning
  * Fix travis warning
  * use parse actions to evaluate conditions
  * Speed up topological_order by using a per-package cache of all run_depends
  * Fix crash with pyparsing 3
  * [enhancement]evaluating more than 1 condition fixes #277
  * exclude Signed-off-by: lines from changelog
  * Changes 'install' to 'catkin_install_python' in the CMakeLists.txt template
* Wed May 27 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
- use %%pytest
* Mon Mar 30 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 0.4.16
  * add Python 3.7 and 3.8 to Travis matrix
  * allow different CMake minimum version in metapackage
* Fri Jan 24 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 0.4.15
  * small fixes
* Sat Aug  3 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.4.13:
  * small fixes
- Fix download url
* Thu Jul 11 2019 Andreas Färber <afaerber@suse.de>
- Initial (v0.4.12)
